@@ -10,3 +10,7 @@ def set_url(source_file, config):
 
 set_url.require_before = ['root_url']
 set_url.require_after = ['url']
+
+set_url.dont_inherit = [
+    'url'
+]
