@@ -136,7 +136,10 @@ class Node(object):
         current = self
         ret = []
         while current.parent:
-            ret.insert(0, current.parent)
+            try:
+                ret.insert(0, current.parent.index)
+            except AttributeError:
+                ret.insert(0, current.parent)
             current = current.parent
 
         return ret
@@ -194,6 +197,18 @@ class Node(object):
 
         return prefix + url
 
+    @property
+    @check_config_first
+    def index(self):
+        """
+        If the node contains a child that `is_index`, this method returns that
+        page.
+        """
+        for page in self.children:
+            if page.config.get('is_index'):
+                return page
+        raise AttributeError('index')
+
     @property
     @check_config_first
     def type(self):
@@ -247,8 +262,8 @@ class Node(object):
 
         child_by_name = [child for child in self.children if child.name == key]
         if len(child_by_name) > 1:
-            raise KeyError('There are multiple results for the node named "{}" '
-                'in folder "{}"'.format(key, self.name))
+            raise KeyError('There are multiple results for the node named "{0}" '
+                'in folder "{1}"'.format(key, self.name))
         elif child_by_name:
             return child_by_name[0]
 
